pystagram.graph_api.components.fields package — pystagram 0.1 documentation

# pystagram.graph_api.components.fields package

## Submodules

## pystagram.graph_api.components.fields.account_fields module

class pystagram.graph_api.components.fields.account_fields.AccountFields(value)

  Bases: `Fields`

  An enumeration.

  ABOUT = 'about'
  AB_TESTS = 'ab_tests'
  ACCESS_TOKEN = 'access_token'
  ADS_POSTS = 'ads_posts'
  AD_CAMPAIGN = 'ad_campaign'
  AFFILIATION = 'affiliation'
  AGENCIES = 'agencies'
  ALBUMS = 'albums'
  APP_ID = 'app_id'
  ARTISTS_WE_LIKE = 'artists_we_like'
  AR_EXPERIENCE = 'ar_experience'
  ASSIGNED_USERS = 'assigned_users'
  ATTIRE = 'attire'
  AUDIO_MEDIA_COPYRIGHTS = 'audio_media_copyrights'
  AVAILABLE_PROMO_OFFER_IDS = 'available_promo_offer_ids'
  AWARDS = 'awards'
  BAND_INTERESTS = 'band_interests'
  BAND_MEMBERS = 'band_members'
  BEST_PAGE = 'best_page'
  BIO = 'bio'
  BIRTHDAY = 'birthday'
  BLOCKED = 'blocked'
  BOOKING_AGENT = 'booking_agent'
  BUILT = 'built'
  BUSINESS = 'business'
  BUSINESSPROJECTS = 'businessprojects'
  CALL_TO_ACTIONS = 'call_to_actions'
  CANVASES = 'canvases'
  CANVAS_ELEMENTS = 'canvas_elements'
  CAN_CHECKIN = 'can_checkin'
  CAN_POST = 'can_post'
  CATEGORY = 'category'
  CATEGORY_LIST = 'category_list'
  CHAT_PLUGIN = 'chat_plugin'
  CHECKINS = 'checkins'
  COMMERCE_MERCHANT_SETTINGS = 'commerce_merchant_settings'
  COMMERCE_ORDERS = 'commerce_orders'
  COMMERCE_PAYOUTS = 'commerce_payouts'
  COMMERCE_TRANSACTIONS = 'commerce_transactions'
  COMPANY_OVERVIEW = 'company_overview'
  CONNECTED_INSTAGRAM_ACCOUNT = 'connected_instagram_account'
  CONNECTED_PAGE_BACKED_INSTAGRAM_ACCOUNT = 'connected_page_backed_instagram_account'
  CONTACT_ADDRESS = 'contact_address'
  CONVERSATIONS = 'conversations'
  COPYRIGHT_ATTRIBUTION_INSIGHTS = 'copyright_attribution_insights'
  COPYRIGHT_WHITELISTED_IG_PARTNERS = 'copyright_whitelisted_ig_partners'
  COUNTRY_PAGE_LIKES = 'country_page_likes'
  COVER = 'cover'
  CROSSPOST_WHITELISTED_PAGES = 'crosspost_whitelisted_pages'
  CULINARY_TEAM = 'culinary_team'
  CURRENT_LOCATION = 'current_location'
  CUSTOM_LABELS = 'custom_labels'
  CUSTOM_USER_SETTINGS = 'custom_user_settings'
  DATASET = 'dataset'
  DELIVERY_AND_PICKUP_OPTION_INFO = 'delivery_and_pickup_option_info'
  DESCRIPTION = 'description'
  DESCRIPTION_HTML = 'description_html'
  DIFFERENTLY_OPEN_OFFERINGS = 'differently_open_offerings'
  DIRECTED_BY = 'directed_by'
  DISPLAYED_MESSAGE_RESPONSE_TIME = 'displayed_message_response_time'
  DISPLAY_SUBTEXT = 'display_subtext'
  DOES_VIEWER_HAVE_PAGE_PERMISSION_LINK_IG = 'does_viewer_have_page_permission_link_ig'
  EMAILS = 'emails'
  ENGAGEMENT = 'engagement'
  EVENTS = 'events'
  FANTASY_GAMES = 'fantasy_games'
  FAN_COUNT = 'fan_count'
  FEATURED_VIDEO = 'featured_video'
  FEATURES = 'features'
  FEED = 'feed'
  FOLLOWERS_COUNT = 'followers_count'
  FOOD_STYLES = 'food_styles'
  FOUNDED = 'founded'
  GENERAL_INFO = 'general_info'
  GENERAL_MANAGER = 'general_manager'
  GENRE = 'genre'
  GLOBAL_BRAND_CHILDREN = 'global_brand_children'
  GLOBAL_BRAND_PAGE_NAME = 'global_brand_page_name'
  GLOBAL_BRAND_ROOT_ID = 'global_brand_root_id'
  GROUPS = 'groups'
  HAS_ADDED_APP = 'has_added_app'
  HAS_LEAD_ACCESS = 'has_lead_access'
  HAS_TRANSITIONED_TO_NEW_PAGE_EXPERIENCE = 'has_transitioned_to_new_page_experience'
  HAS_WHATSAPP_BUSINESS_NUMBER = 'has_whatsapp_business_number'
  HAS_WHATSAPP_NUMBER = 'has_whatsapp_number'
  HOMETOWN = 'hometown'
  HOURS = 'hours'
  ID = 'id'
  IMAGE_COPYRIGHTS = 'image_copyrights'
  IMPRESSUM = 'impressum'
  INDEXED_VIDEOS = 'indexed_videos'
  INFLUENCES = 'influences'
  INSIGHTS = 'insights'
  INSTAGRAM_ACCOUNTS = 'instagram_accounts'
  INSTAGRAM_BUSINESS_ACCOUNT = 'instagram_business_account'
  IS_ALWAYS_OPEN = 'is_always_open'
  IS_CHAIN = 'is_chain'
  IS_COMMUNITY_PAGE = 'is_community_page'
  IS_ELIGIBLE_FOR_BRANDED_CONTENT = 'is_eligible_for_branded_content'
  IS_ELIGIBLE_FOR_DISABLE_CONNECT_IG_BTN_FOR_NON_PAGE_ADMIN_AM_WEB = 'is_eligible_for_disable_connect_ig_btn_for_non_page_admin_am_web'
  IS_MESSENGER_BOT_GET_STARTED_ENABLED = 'is_messenger_bot_get_started_enabled'
  IS_MESSENGER_PLATFORM_BOT = 'is_messenger_platform_bot'
  IS_OWNED = 'is_owned'
  IS_PERMANENTLY_CLOSED = 'is_permanently_closed'
  IS_PUBLISHED = 'is_published'
  IS_UNCLAIMED = 'is_unclaimed'
  IS_WEBHOOKS_SUBSCRIBED = 'is_webhooks_subscribed'
  LEADGEN_FORMS = 'leadgen_forms'
  LEADGEN_TOS_ACCEPTANCE_TIME = 'leadgen_tos_acceptance_time'
  LEADGEN_TOS_ACCEPTED = 'leadgen_tos_accepted'
  LEADGEN_TOS_ACCEPTING_USER = 'leadgen_tos_accepting_user'
  LIKES = 'likes'
  LINK = 'link'
  LIVE_VIDEOS = 'live_videos'
  LOCATION = 'location'
  LOCATIONS = 'locations'
  MEDIA_FINGERPRINTS = 'media_fingerprints'
  MEMBERS = 'members'
  MERCHANT_ID = 'merchant_id'
  MERCHANT_REVIEW_STATUS = 'merchant_review_status'
  MESSAGING_FEATURE_REVIEW = 'messaging_feature_review'
  MESSAGING_FEATURE_STATUS = 'messaging_feature_status'
  MESSENGER_ADS_DEFAULT_ICEBREAKERS = 'messenger_ads_default_icebreakers'
  MESSENGER_ADS_DEFAULT_QUICK_REPLIES = 'messenger_ads_default_quick_replies'
  MESSENGER_ADS_QUICK_REPLIES_TYPE = 'messenger_ads_quick_replies_type'
  MESSENGER_LEAD_FORMS = 'messenger_lead_forms'
  MESSENGER_PROFILE = 'messenger_profile'
  MISSION = 'mission'
  MPG = 'mpg'
  NAME = 'name'
  NAME_WITH_LOCATION_DESCRIPTOR = 'name_with_location_descriptor'
  NETWORK = 'network'
  NEW_LIKE_COUNT = 'new_like_count'
  NOTIFICATION_MESSAGE_TOKENS = 'notification_message_tokens'
  OFFER_ELIGIBLE = 'offer_eligible'
  OVERALL_STAR_RATING = 'overall_star_rating'
  PAGE_BACKED_INSTAGRAM_ACCOUNTS = 'page_backed_instagram_accounts'
  PAGE_TOKEN = 'page_token'
  PARENT_PAGE = 'parent_page'
  PARKING = 'parking'
  PAYMENT_OPTIONS = 'payment_options'
  PERSONAL_INFO = 'personal_info'
  PERSONAL_INTERESTS = 'personal_interests'
  PERSONAS = 'personas'
  PHARMA_SAFETY_INFO = 'pharma_safety_info'
  PHONE = 'phone'
  PHOTOS = 'photos'
  PICKUP_OPTIONS = 'pickup_options'
  PICTURE = 'picture'
  PLACE_TYPE = 'place_type'
  PLOT_OUTLINE = 'plot_outline'
  POSTS = 'posts'
  PREFERRED_AUDIENCE = 'preferred_audience'
  PRESS_CONTACT = 'press_contact'
  PRICE_RANGE = 'price_range'
  PRIVACY_INFO_URL = 'privacy_info_url'
  PRODUCED_BY = 'produced_by'
  PRODUCTS = 'products'
  PRODUCT_CATALOGS = 'product_catalogs'
  PROMOTION_ELIGIBLE = 'promotion_eligible'
  PROMOTION_INELIGIBLE_REASON = 'promotion_ineligible_reason'
  PUBLIC_TRANSIT = 'public_transit'
  PUBLISHED_POSTS = 'published_posts'
  RATINGS = 'ratings'
  RATING_COUNT = 'rating_count'
  RECIPIENT = 'recipient'
  RECORD_LABEL = 'record_label'
  RELEASE_DATE = 'release_date'
  RESTAURANT_SERVICES = 'restaurant_services'
  RESTAURANT_SPECIALTIES = 'restaurant_specialties'
  ROLES = 'roles'
  RTB_DYNAMIC_POSTS = 'rtb_dynamic_posts'
  SCHEDULE = 'schedule'
  SCHEDULED_POSTS = 'scheduled_posts'
  SCREENPLAY_BY = 'screenplay_by'
  SEASON = 'season'
  SECONDARY_RECEIVERS = 'secondary_receivers'
  SETTINGS = 'settings'
  SHOP_SETUP_STATUS = 'shop_setup_status'
  SINGLE_LINE_ADDRESS = 'single_line_address'
  STARRING = 'starring'
  START_INFO = 'start_info'
  STORE_CODE = 'store_code'
  STORE_LOCATION_DESCRIPTOR = 'store_location_descriptor'
  STORE_NUMBER = 'store_number'
  STORIES = 'stories'
  STUDIO = 'studio'
  SUBSCRIBED_APPS = 'subscribed_apps'
  SUPPORTS_DONATE_BUTTON_IN_LIVE_VIDEO = 'supports_donate_button_in_live_video'
  TABS = 'tabs'
  TAGGED = 'tagged'
  TALKING_ABOUT_COUNT = 'talking_about_count'
  TASKS = 'tasks'
  TEMPORARY_STATUS = 'temporary_status'
  THREADS = 'threads'
  THREAD_OWNER = 'thread_owner'
  UNREAD_MESSAGE_COUNT = 'unread_message_count'
  UNREAD_NOTIF_COUNT = 'unread_notif_count'
  UNSEEN_MESSAGE_COUNT = 'unseen_message_count'
  USERNAME = 'username'
  VERIFICATION_STATUS = 'verification_status'
  VIDEOS = 'videos'
  VIDEO_COPYRIGHT_RULES = 'video_copyright_rules'
  VIDEO_LISTS = 'video_lists'
  VIDEO_REELS = 'video_reels'
  VISITOR_POSTS = 'visitor_posts'
  VOIP_INFO = 'voip_info'
  WEBSITE = 'website'
  WELCOME_MESSAGE_FLOWS = 'welcome_message_flows'
  WERE_HERE_COUNT = 'were_here_count'
  WHATSAPP_NUMBER = 'whatsapp_number'
  WRITTEN_BY = 'written_by'

## pystagram.graph_api.components.fields.base_fields module

class pystagram.graph_api.components.fields.base_fields.BaseFields(name, bases, namespace, **kwargs)

  Bases: `ABCMeta`, `EnumMeta`

## pystagram.graph_api.components.fields.catalog_fields module

class pystagram.graph_api.components.fields.catalog_fields.CatalogFields(value)

  Bases: `Fields`

  An enumeration.

  CATALOG_ID = 'catalog_id'
  CATALOG_NAME = 'catalog_name'
  PRODUCT_COUNT = 'product_count'
  SHOP_NAME = 'shop_name'

## pystagram.graph_api.components.fields.comment_fields module

class pystagram.graph_api.components.fields.comment_fields.CommentFields(value)

  Bases: `Fields`

  An enumeration.

  ID = 'id'
  LIKE_COUNT = 'like_count'
  MEDIA = 'media'
  TEXT = 'text'
  TIMESTAMP = 'timestamp'

## pystagram.graph_api.components.fields.container_fields module

class pystagram.graph_api.components.fields.container_fields.ContainerFields(value)

  Bases: `Fields`

  An enumeration.

  COPYRIGHT_CHECK_STATUS = 'copyright_check_status'
  ID = 'id'
  STATUS = 'status'
  STATUS_CODE = 'status_code'

## pystagram.graph_api.components.fields.fields module

class pystagram.graph_api.components.fields.fields.Fields(value)

  Bases: `str`, `Enum`

  An enumeration.

  classmethod list()

## pystagram.graph_api.components.fields.hashtag_fields module

class pystagram.graph_api.components.fields.hashtag_fields.HashtagFields(value)

  Bases: `Fields`

  An enumeration.

  ID = 'id'
  NAME = 'name'

## pystagram.graph_api.components.fields.me_fields module

class pystagram.graph_api.components.fields.me_fields.MeFields(value)

  Bases: `Fields`

  An enumeration.

  ABOUT = 'about'
  ACCOUNTS = 'accounts'
  ADACCOUNTS = 'adaccounts'
  AD_STUDIES = 'ad_studies'
  AGE_RANGE = 'age_range'
  ALBUMS = 'albums'
  APPREQUESTFORMERRECIPIENTS = 'apprequestformerrecipients'
  APPREQUESTS = 'apprequests'
  ASSIGNED_AD_ACCOUNTS = 'assigned_ad_accounts'
  ASSIGNED_BUSINESS_ASSET_GROUPS = 'assigned_business_asset_groups'
  ASSIGNED_PAGES = 'assigned_pages'
  ASSIGNED_PRODUCT_CATALOGS = 'assigned_product_catalogs'
  BIRTHDAY = 'birthday'
  BUSINESSES = 'businesses'
  BUSINESS_USERS = 'business_users'
  CONVERSATIONS = 'conversations'
  CUSTOM_LABELS = 'custom_labels'
  EDUCATION = 'education'
  EMAIL = 'email'
  EVENTS = 'events'
  FAVORITE_ATHLETES = 'favorite_athletes'
  FAVORITE_TEAMS = 'favorite_teams'
  FEED = 'feed'
  FIRST_NAME = 'first_name'
  FRIENDS = 'friends'
  FUNDRAISERS = 'fundraisers'
  GENDER = 'gender'
  GROUPS = 'groups'
  HOMETOWN = 'hometown'
  ID = 'id'
  IDS_FOR_APPS = 'ids_for_apps'
  IDS_FOR_BUSINESS = 'ids_for_business'
  IDS_FOR_PAGES = 'ids_for_pages'
  ID_FOR_AVATARS = 'id_for_avatars'
  INSPIRATIONAL_PEOPLE = 'inspirational_people'
  INSTALLED = 'installed'
  INSTALL_TYPE = 'install_type'
  IS_GUEST_USER = 'is_guest_user'
  LANGUAGES = 'languages'
  LAST_NAME = 'last_name'
  LIKES = 'likes'
  LINK = 'link'
  LIVE_VIDEOS = 'live_videos'
  LOCATION = 'location'
  MEETING_FOR = 'meeting_for'
  MIDDLE_NAME = 'middle_name'
  MUSIC = 'music'
  NAME = 'name'
  NAME_FORMAT = 'name_format'
  PAYMENT_PRICEPOINTS = 'payment_pricepoints'
  PAYMENT_SUBSCRIPTIONS = 'payment.subscriptions'
  PAYMENT_TRANSACTIONS = 'payment_transactions'
  PERMISSIONS = 'permissions'
  PERSONAL_AD_ACCOUNTS = 'personal_ad_accounts'
  PHOTOS = 'photos'
  PICTURE = 'picture'
  POLITICAL = 'political'
  POSTS = 'posts'
  PROFILE_PIC = 'profile_pic'
  QUOTES = 'quotes'
  RELATIONSHIP_STATUS = 'relationship_status'
  RICH_MEDIA_DOCUMENTS = 'rich_media_documents'
  SHARED_LOGIN_UPGRADE_REQUIRED_BY = 'shared_login_upgrade_required_by'
  SHORT_NAME = 'short_name'
  SIGNIFICANT_OTHER = 'significant_other'
  SPORTS = 'sports'
  SUPPORTS_DONATE_BUTTON_IN_LIVE_VIDEO = 'supports_donate_button_in_live_video'
  TOKEN_FOR_BUSINESS = 'token_for_business'
  VIDEOS = 'videos'
  VIDEO_UPLOAD_LIMITS = 'video_upload_limits'
  WEBSITE = 'website'

## pystagram.graph_api.components.fields.media_fields module

class pystagram.graph_api.components.fields.media_fields.MediaFields(value)

  Bases: `Fields`

  An enumeration.

  CAPTION = 'caption'
  CHILDREN = 'children'
  COMMENTS_COUNT = 'comments_count'
  COPYRIGHT_CHECK_INFORMATION_STATUS = 'copyright_check_information.status'
  ID = 'id'
  IG_ID = 'ig_id'
  IS_COMMENT_ENABLED = 'is_comment_enabled'
  IS_SHARED_TO_FEED = 'is_shared_to_feed'
  LIKE_COUNT = 'like_count'
  MEDIA_PRODUCT_TYPE = 'media_product_type'
  MEDIA_TYPE = 'media_type'
  MEDIA_URL = 'media_url'
  OWNER = 'owner'
  PERMALINK = 'permalink'
  SHORTCODE = 'shortcode'
  THUMBNAIL_URL = 'thumbnail_url'
  TIMESTAMP = 'timestamp'
  USERNAME = 'username'
  VIDEO_TITLE = 'video_title'

## pystagram.graph_api.components.fields.publishing_limit_fields module

class pystagram.graph_api.components.fields.publishing_limit_fields.PublishingLimitFields(value)

  Bases: `Fields`

  An enumeration.

  CONFIG = 'config'
  QUOTA_USAGE = 'quota_usage'

## pystagram.graph_api.components.fields.user_fields module

class pystagram.graph_api.components.fields.user_fields.UserFields(value)

  Bases: `Fields`

  An enumeration.

  BIO = 'bio'
  BUSINESS_ACCOUNT = 'business_account'
  FOLLOWERS_COUNT = 'followers_count'
  FOLLOWING_COUNT = 'following_count'
  ID = 'id'
  IS_PRIVATE = 'is_private'
  IS_VERIFIED = 'is_verified'
  MEDIA_COUNT = 'media_count'
  NAME = 'name'
  PROFILE_PICTURE_URL = 'profile_picture_url'
  USERNAME = 'username'
  WEBSITE = 'website'

## Module contents